@@ -45,12 +45,13 @@ class SlashCommand:
                  sync_commands: bool = False,
                  delete_from_unused_guilds: bool = False,
                  sync_on_cog_reload: bool = False,
-                 override_type: bool = False):
+                 override_type: bool = False,
+                 application_id: typing.Optional[int] = None):
         self._discord = client
         self.commands = {}
         self.subcommands = {}
         self.logger = logging.getLogger("discord_slash")
-        self.req = http.SlashCommandRequest(self.logger, self._discord)
+        self.req = http.SlashCommandRequest(self.logger, self._discord, application_id)
         self.sync_commands = sync_commands
         self.sync_on_cog_reload = sync_on_cog_reload
 
@@ -327,6 +328,10 @@ class SlashCommand:
         """
         Registers slash command to SlashCommand.
 
+        .. warning::
+            Just using this won't register slash command to Discord API.
+            To register it, check :meth:`.utils.manage_commands.add_slash_command` or simply enable `sync_commands`.
+
         :param cmd: Command Coroutine.
         :type cmd: Coroutine
         :param name: Name of the slash command. Default name of the coroutine.
@@ -344,6 +349,7 @@ class SlashCommand:
         """
         name = name or cmd.__name__
         name = name.lower()
+        guild_ids = guild_ids if guild_ids else []
         if name in self.commands:
             tgt = self.commands[name]
             if not tgt.has_subcommands:
@@ -411,6 +417,7 @@ class SlashCommand:
         name = name or cmd.__name__
         name = name.lower()
         description = description or getdoc(cmd)
+        guild_ids = guild_ids if guild_ids else []
 
         if base in self.commands:
             for x in guild_ids:
@@ -720,11 +727,8 @@ class SlashCommand:
 
             selected_cmd = self.commands[to_use["data"]["name"]]
 
-            if selected_cmd.allowed_guild_ids:
-                guild_id = ctx.guild.id if isinstance(ctx.guild, discord.Guild) else ctx.guild
-
-                if guild_id not in selected_cmd.allowed_guild_ids:
-                    return
+            if selected_cmd.allowed_guild_ids and ctx.guild_id not in selected_cmd.allowed_guild_ids:
+                return
 
             if selected_cmd.has_subcommands and not selected_cmd.func:
                 return await self.handle_subcommand(ctx, to_use)
@@ -738,7 +742,7 @@ class SlashCommand:
             # does not give option type from API.
             temporary_auto_convert = {}
             for x in selected_cmd.options:
-                temporary_auto_convert[x["name"]] = x["type"]
+                temporary_auto_convert[x["name"].lower()] = x["type"]
 
             args = await self.process_options(ctx.guild, to_use["data"]["options"], selected_cmd.connector, temporary_auto_convert) \
                 if "options" in to_use["data"] else {}
@@ -764,7 +768,7 @@ class SlashCommand:
         sub_name = sub["name"]
         if sub_name not in base:
             return
-        ctx.subcommand = sub_name
+        ctx.subcommand_name = sub_name
         sub_opts = sub["options"] if "options" in sub else []
         for x in sub_opts:
             if "options" in x or "value" not in x:
@@ -778,7 +782,7 @@ class SlashCommand:
                 # does not give option type from API.
                 temporary_auto_convert = {}
                 for n in selected.options:
-                    temporary_auto_convert[n["name"]] = n["type"]
+                    temporary_auto_convert[n["name"].lower()] = n["type"]
 
                 args = await self.process_options(ctx.guild, x["options"], selected.connector, temporary_auto_convert) \
                     if "options" in x else {}
@@ -791,7 +795,7 @@ class SlashCommand:
         # does not give option type from API.
         temporary_auto_convert = {}
         for n in selected.options:
-            temporary_auto_convert[n["name"]] = n["type"]
+            temporary_auto_convert[n["name"].lower()] = n["type"]
 
         args = await self.process_options(ctx.guild, sub_opts, selected.connector, temporary_auto_convert) \
             if "options" in sub else {}
