@@ -54,3 +54,8 @@ class IncorrectType(SlashCommandError):
     """
     Type passed was incorrect
     """
+
+class AlreadyResponded(SlashCommandError):
+    """
+    The interaction was already responded to
+    """
\ No newline at end of file
